==> coventry-0.8.1.tar.gz: coventry-0.8.1/cmake/features.cmake <==
# Copyright (C) 2020 Tycho Softworks.
#
# This file is free software; as a special exception the author gives
# unlimited permission to copy and/or distribute it, with or without
# modifications, as long as this notice is preserved.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY, to the extent permitted by law; without even the
# implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

include(CheckCXXSourceCompiles)
include(CheckIncludeFileCXX)
include(CheckFunctionExists)
include(FindPkgConfig)

check_include_file_cxx(mqueue.h FOUND_MQUEUE)
if(FOUND_MQUEUE)
    set(RT_LIBRARIES rt)
else()
    message(FATAL_ERROR "posix mqueue support required")
endif()

set(CMAKE_THREAD_PREFER_PTHREAD TRUE)
set(THREADS_PREFER_PTHREAD_FLAG TRUE)

find_package(Threads REQUIRED)
find_package(OpenSSL REQUIRED)
find_package(fmt CONFIG REQUIRED)

pkg_check_modules(MODERNCLI moderncli>=0.8.0 REQUIRED)
include_directories(${MODERNCLI_INCLUDE_DIRS})

pkg_check_modules(OSIP2 libosip2>=5.3.0 REQUIRED)
include_directories(${OSIP2_INCLUDE_DIRS})
link_directories(${OSIP2_LIBRARY_DIRS})

if(BUILD_SYSTEMD)
    pkg_check_modules(SYSTEMD libsystemd REQUIRED)
    include_directories(${SYSTEMD_INCLUDE_DIRS})
    link_directories(${SYSTEMD_LIBRARY_DIRS})
    add_definitions("-DSYSTEMD_SERVICE")
endif()

set(SYSTEM_LIBS OpenSSL::Crypto Threads::Threads)
set(EXOSIP_LIBS eXosip2 osipparser2 osip2 ${SYSTEM_LIBS})

if(CMAKE_BUILD_TYPE MATCHES "Debug")
    set(BUILD_DEBUG true)
    add_definitions(-DDEBUG)
else()
    add_definitions(-DNDEBUG)
    pkg_search_module(MALLOC jemalloc IMPORTED_TARGET)
endif()

==> coventry-0.8.6.tar.gz: coventry-0.8.6/cmake/features.cmake <==
# Copyright (C) 2020 Tycho Softworks.
#
# This file is free software; as a special exception the author gives
# unlimited permission to copy and/or distribute it, with or without
# modifications, as long as this notice is preserved.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY, to the extent permitted by law; without even the
# implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

include(CheckCXXSourceCompiles)
include(CheckIncludeFileCXX)
include(CheckFunctionExists)
include(FindPkgConfig)

check_include_file_cxx(mqueue.h FOUND_MQUEUE)
if(FOUND_MQUEUE)
    set(RT_LIBRARIES rt)
else()
    message(FATAL_ERROR "posix mqueue support required")
endif()

set(CMAKE_THREAD_PREFER_PTHREAD TRUE)
set(THREADS_PREFER_PTHREAD_FLAG TRUE)

find_package(Threads REQUIRED)
find_package(OpenSSL REQUIRED)
find_package(fmt CONFIG REQUIRED)

pkg_check_modules(MODERNCLI moderncli>=0.9.0 REQUIRED)
include_directories(${MODERNCLI_PREFIX}/include ${MODERNCLI_INCLUDEDIR})

pkg_check_modules(OSIP2 libosip2>=5.3.0 REQUIRED)
include_directories(${OSIP2_INCLUDE_DIRS})
link_directories(${OSIP2_LIBRARY_DIRS})

if(BUILD_SYSTEMD)
    pkg_check_modules(SYSTEMD libsystemd REQUIRED)
    include_directories(${SYSTEMD_INCLUDE_DIRS})
    link_directories(${SYSTEMD_LIBRARY_DIRS})
    add_definitions("-DSYSTEMD_SERVICE")
endif()

set(SYSTEM_LIBS OpenSSL::Crypto Threads::Threads)
set(EXOSIP_LIBS eXosip2 osipparser2 osip2 ${SYSTEM_LIBS})

if(CMAKE_BUILD_TYPE MATCHES "Debug")
    set(BUILD_DEBUG true)
    add_definitions(-DDEBUG)
else()
    add_definitions(-DNDEBUG)
    pkg_search_module(MALLOC jemalloc IMPORTED_TARGET)
endif()
